summaryrefslogtreecommitdiffhomepage
path: root/src/raylib.h
diff options
context:
space:
mode:
authorRay <[email protected]>2021-04-20 12:16:16 +0200
committerRay <[email protected]>2021-04-20 12:16:16 +0200
commitbb743e8c6ec1ab50bd5ab0f12e10a48da702d76a (patch)
tree6135bf9acde7a8418579b8e42cd9469e01dd70a4 /src/raylib.h
parentf90368606026697d55e7d91a71d114cbc1680f82 (diff)
downloadraylib-bb743e8c6ec1ab50bd5ab0f12e10a48da702d76a.tar.gz
raylib-bb743e8c6ec1ab50bd5ab0f12e10a48da702d76a.zip
ADDED: UpdateMeshBuffer()
Diffstat (limited to 'src/raylib.h')
-rw-r--r--src/raylib.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/raylib.h b/src/raylib.h
index 4c70e48a..abe7d8a1 100644
--- a/src/raylib.h
+++ b/src/raylib.h
@@ -1381,7 +1381,8 @@ RLAPI void UnloadModel(Model model);
RLAPI void UnloadModelKeepMeshes(Model model); // Unload model (but not meshes) from memory (RAM and/or VRAM)
// Mesh loading/unloading functions
-RLAPI void UploadMesh(Mesh *mesh, bool dynamic); // Upload vertex data into GPU and provided VAO/VBO ids
+RLAPI void UploadMesh(Mesh *mesh, bool dynamic); // Upload mesh vertex data in GPU and provide VAO/VBO ids
+RLAPI void UpdateMeshBuffer(Mesh mesh, int index, void *data, int dataSize, int offset); // Update mesh vertex data in GPU for a specific buffer index
RLAPI void DrawMesh(Mesh mesh, Material material, Matrix transform); // Draw a 3d mesh with material and transform
RLAPI void DrawMeshInstanced(Mesh mesh, Material material, Matrix *transforms, int instances); // Draw multiple mesh instances with material and different transforms
RLAPI void UnloadMesh(Mesh mesh); // Unload mesh data from CPU and GPU